@@ -5,12 +5,12 @@
 namespace fz {
 
 namespace uri_chars {
-std::string const alpha{ "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" };
-std::string const digit{ "01234567890" };
-std::string const scheme{ alpha + digit + "+-." };
+constexpr std::string_view alpha{ "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" };
+constexpr std::string_view digit{ "01234567890" };
+constexpr std::string_view scheme{ "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+-." };
 }
 
-uri::uri(std::string const& in)
+uri::uri(std::string_view const& in)
 {
 	if (!parse(in)) {
 		clear();
@@ -22,7 +22,7 @@ void uri::clear()
 	*this = uri();
 }
 
-bool uri::parse(std::string in)
+bool uri::parse(std::string_view in)
 {
 	// Look for fragment
 	size_t pos = in.find('#');
@@ -57,7 +57,7 @@ bool uri::parse(std::string in)
 		}
 		else {
 			authority = in.substr(2);
-			in.clear();
+			in = std::string_view();
 		}
 		if (!parse_authority(std::move(authority))) {
 			return false;
@@ -65,7 +65,7 @@ bool uri::parse(std::string in)
 	}
 
 	if (!in.empty()) {
-		path_ = percent_decode(in);
+		path_ = percent_decode_s(in);
 		if (path_.empty()) {
 			return false;
 		}
@@ -83,11 +83,11 @@ bool uri::parse_authority(std::string && authority)
 		authority = authority.substr(pos + 1);
 		pos = userinfo.find(':');
 		if (pos != std::string::npos) { // Slight inaccuracy: Empty password isn't handled well
-			user_ = percent_decode(userinfo.substr(0, pos));
+			user_ = percent_decode_s(userinfo.substr(0, pos));
 			if (user_.empty() && pos != 0) {
 				return false;
 			}
-			pass_ = percent_decode(userinfo.substr(pos + 1));
+			pass_ = percent_decode_s(userinfo.substr(pos + 1));
 			if (pass_.empty() && pos + 1 != userinfo.size()) {
 				return false;
 			}
@@ -114,7 +114,7 @@ bool uri::parse_authority(std::string && authority)
 			return false;
 		}
 	}
-	host_ = percent_decode(authority);
+	host_ = percent_decode_s(authority);
 	if (host_.empty() && !authority.empty()) {
 		return false;
 	}
@@ -227,7 +227,7 @@ bool uri::operator==(uri const& arg) const
 }
 
 
-query_string::query_string(std::string const& raw)
+query_string::query_string(std::string_view const& raw)
 {
 	set(raw);
 }
@@ -246,7 +246,7 @@ query_string::query_string(std::initializer_list<std::pair<std::string, std::str
 	}
 }
 
-bool query_string::set(std::string const& raw)
+bool query_string::set(std::string_view const& raw)
 {
 	segments_.clear();
 
@@ -257,13 +257,13 @@ bool query_string::set(std::string const& raw)
 			return false;
 		}
 
-		std::string key = percent_decode(token.substr(0, pos));
+		std::string key = percent_decode_s(token.substr(0, pos));
 		if (key.empty()) {
 			return false;
 		}
 		std::string value;
 		if (pos != std::string::npos) {
-			value = percent_decode(token.substr(pos + 1));
+			value = percent_decode_s(token.substr(pos + 1));
 			if (value.empty() && pos + 1 != token.size()) {
 				return false;
 			}
